pub struct WitLanguage {}Trait Implementations
Sourceimpl<'config> Builder<WitLanguage> for WitBuilder<'config>
impl<'config> Builder<WitLanguage> for WitBuilder<'config>
Sourcefn build<'a, S: Source + ?Sized>(
&self,
source: &S,
edits: &[TextEdit],
_cache: &'a mut impl BuilderCache<WitLanguage>,
) -> BuildOutput<WitLanguage>
fn build<'a, S: Source + ?Sized>( &self, source: &S, edits: &[TextEdit], _cache: &'a mut impl BuilderCache<WitLanguage>, ) -> BuildOutput<WitLanguage>
Builds the structure from the source text.
Sourceimpl Clone for WitLanguage
impl Clone for WitLanguage
Sourcefn clone(&self) -> WitLanguage
fn clone(&self) -> WitLanguage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WitLanguage
impl Debug for WitLanguage
Sourceimpl Default for WitLanguage
impl Default for WitLanguage
Sourcefn default() -> WitLanguage
fn default() -> WitLanguage
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for WitLanguage
impl<'de> Deserialize<'de> for WitLanguage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Language for WitLanguage
impl Language for WitLanguage
Sourceconst CATEGORY: LanguageCategory = LanguageCategory::Dsl
const CATEGORY: LanguageCategory = LanguageCategory::Dsl
The category of the language.
Sourcetype TokenType = WitTokenType
type TokenType = WitTokenType
The token type used to represent different token and node types in the language. Read more
Sourcetype ElementType = WitElementType
type ElementType = WitElementType
The element type used to represent composite structures in the parsed tree. Read more
Sourceimpl<'config> Lexer<WitLanguage> for WitLexer<'config>
impl<'config> Lexer<WitLanguage> for WitLexer<'config>
Sourcefn lex<'a, S: Source + ?Sized>(
&self,
source: &S,
_edits: &[TextEdit],
cache: &'a mut impl LexerCache<WitLanguage>,
) -> LexOutput<WitLanguage>
fn lex<'a, S: Source + ?Sized>( &self, source: &S, _edits: &[TextEdit], cache: &'a mut impl LexerCache<WitLanguage>, ) -> LexOutput<WitLanguage>
Tokenizes the given source text into a sequence of tokens. Read more
Sourceimpl<'config> Parser<WitLanguage> for WitParser<'config>
impl<'config> Parser<WitLanguage> for WitParser<'config>
Sourcefn parse<'a, S: Source + ?Sized>(
&self,
text: &'a S,
edits: &[TextEdit],
cache: &'a mut impl ParseCache<WitLanguage>,
) -> ParseOutput<'a, WitLanguage>
fn parse<'a, S: Source + ?Sized>( &self, text: &'a S, edits: &[TextEdit], cache: &'a mut impl ParseCache<WitLanguage>, ) -> ParseOutput<'a, WitLanguage>
The core parsing entry point. Read more
Sourceimpl Serialize for WitLanguage
impl Serialize for WitLanguage
impl Copy for WitLanguage